@@ -33,7 +33,7 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
  * THE POSSIBILITY OF SUCH DAMAGES.
  *
- * $Id: if_athvar.h 3856 2008-09-02 21:30:32Z proski $
+ * $Id: if_athvar.h 4086 2009-08-13 17:00:26Z proski $
  */
 
 /*
@@ -79,7 +79,7 @@ typedef void *TQUEUE_ARG;
 #endif /* !DECLARE_TASKLET */
 
 #include <linux/sched.h>
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,5,41)
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,5,41)) && !defined(INIT_WORK)
 #include <linux/tqueue.h>
 #define work_struct			tq_struct
 #define schedule_work(t)		schedule_task((t))
@@ -103,11 +103,13 @@ typedef void *TQUEUE_ARG;
 /*
  * Guess how the interrupt handler should work.
  */
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,29)
 #if !defined(IRQ_NONE)
 typedef void irqreturn_t;
 #define	IRQ_NONE
 #define	IRQ_HANDLED
 #endif /* !defined(IRQ_NONE) */
+#endif /* Linux < 2.6.29 */
 
 #ifndef SET_MODULE_OWNER
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,23)
@@ -338,11 +340,6 @@ enum {
 #define	ATH_KEYMAX	128		/* max key cache size we handle */
 #define	ATH_KEYBYTES	(ATH_KEYMAX / NBBY)	/* storage space in bytes */
 
-#ifdef ATH_REVERSE_ENGINEERING
-#define MIN_REGISTER_ADDRESS	0x0000		/* PCI register addresses are taken as releative to the appropriate BAR */
-#define MAX_REGISTER_ADDRESS	0xc000 		/* AR5212/AR5213 seems to have a 48k address range */
-#define MAX_REGISTER_NAME_LEN	32		/* Maximum length of register nicknames in debug output */
-#endif /* #ifdef ATH_REVERSE_ENGINEERING */
 /*
  * Convert from net80211 layer values to Ath layer values. Hopefully this will
  * be optimised away when the two constants are the same.
@@ -694,7 +691,6 @@ struct ath_softc {
 	unsigned int	sc_stagbeacons:1;	/* use staggered beacons */
 	unsigned int	sc_dfswait:1;		/* waiting on channel for radar detect */
 	unsigned int	sc_ackrate:1;		/* send acks at high bitrate */
-	unsigned int	sc_dfs_cac:1;		/* waiting on channel for radar detect */
 	unsigned int	sc_hasintmit:1;		/* Interference mitigation */
 	unsigned int	sc_useintmit:1;		/* Interference mitigation enabled? */
 	unsigned int	sc_txcont:1;		/* Is continuous transmit enabled? */
@@ -811,10 +807,6 @@ struct ath_softc {
 
 	struct timer_list sc_mib_enable;
 
-#ifdef ATH_REVERSE_ENGINEERING
-	u_int8_t register_snapshot[MAX_REGISTER_ADDRESS];
-#endif /* #ifdef ATH_REVERSE_ENGINEERING */
-
 #ifdef ATH_SUPERG_DYNTURBO
 	struct timer_list sc_dturbo_switch_mode;/* AP scan timer */
 	u_int32_t sc_dturbo_tcount;		/* beacon intval count */
@@ -854,7 +846,9 @@ struct ath_softc {
 						 * received pulses */
 	int sc_radar_ignored;			/* if set, we ignored all 
 						 * detected radars */
-	u_int32_t sc_nexttbtt;
+	u_int32_t sc_nexttbtt;	/* TBTT following the next SWBA, updated only
+				 * by ath_beacon_config() to avoid race
+				 * conditions */
 	u_int64_t sc_last_tsf;
 };
 
@@ -1021,6 +1015,5 @@ void ath_sysctl_unregister(void);
 	  "MadWifi" : \
 	  DEV_NAME(_v->iv_ic->ic_dev))
 
-void ath_radar_detected(struct ath_softc *sc, const char *message);
 
 #endif /* _DEV_ATH_ATHVAR_H */
