@@ -99,7 +99,6 @@
 #include <linux/random.h>
 #include <linux/delay.h>
 #include <linux/cache.h>
-#include <linux/sysctl.h>
 #include <linux/proc_fs.h>
 #include <linux/if_arp.h>
 #include <linux/net.h>		/* for net_random */
@@ -470,10 +469,10 @@ ath_rate_tx_complete(struct ath_softc *sc,
 		int tries = 0;
 		int mrr;
 		int final_ndx;
-		int rate0, tries0, ndx0;
-		int rate1, tries1, ndx1;
-		int rate2, tries2, ndx2;
-		int rate3, tries3, ndx3;
+		int rate0, tries0, ndx0, hwrate0;
+		int rate1, tries1, ndx1, hwrate1;
+		int rate2, tries2, ndx2, hwrate2;
+		int rate3, tries3, ndx3, hwrate3;
 
 		/* This is the index in the retry chain we finish at.
 		 * With no retransmits, it is always 0.
@@ -520,19 +519,31 @@ ath_rate_tx_complete(struct ath_softc *sc,
 		 * call will always return 6,3,2,2. For some packets, we can
 		 * get a mrr of 0, -1, -1, -1, which indicates there is no
 		 * chain installed for that packet */
-		rate0 = sc->sc_hwmap[MS(ds->ds_ctl3, AR_XmitRate0)].ieeerate;
+		if (sc->sc_ah->ah_magic != 0x20065416) {
+			hwrate0 = MS(ds->ds_ctl3, AR_XmitRate0);
+			hwrate1 = MS(ds->ds_ctl3, AR_XmitRate1);
+			hwrate2 = MS(ds->ds_ctl3, AR_XmitRate2);
+			hwrate3 = MS(ds->ds_ctl3, AR_XmitRate3);
+		} else {
+			hwrate0 = MS(ds->ds_ctl3, AR5416_XmitRate0);
+			hwrate1 = MS(ds->ds_ctl3, AR5416_XmitRate1);
+			hwrate2 = MS(ds->ds_ctl3, AR5416_XmitRate2);
+			hwrate3 = MS(ds->ds_ctl3, AR5416_XmitRate3);
+		}
+
+		rate0 = sc->sc_hwmap[hwrate0].ieeerate;
 		tries0 = MS(ds->ds_ctl2, AR_XmitDataTries0);
 		ndx0 = rate_to_ndx(sn, rate0);
 
-		rate1 = sc->sc_hwmap[MS(ds->ds_ctl3, AR_XmitRate1)].ieeerate;
+		rate1 = sc->sc_hwmap[hwrate1].ieeerate;
 		tries1 = MS(ds->ds_ctl2, AR_XmitDataTries1);
 		ndx1 = rate_to_ndx(sn, rate1);
 
-		rate2 = sc->sc_hwmap[MS(ds->ds_ctl3, AR_XmitRate2)].ieeerate;
+		rate2 = sc->sc_hwmap[hwrate2].ieeerate;
 		tries2 = MS(ds->ds_ctl2, AR_XmitDataTries2);
 		ndx2 = rate_to_ndx(sn, rate2);
 
-		rate3 = sc->sc_hwmap[MS(ds->ds_ctl3, AR_XmitRate3)].ieeerate;
+		rate3 = sc->sc_hwmap[hwrate3].ieeerate;
 		tries3 = MS(ds->ds_ctl2, AR_XmitDataTries3);
 		ndx3 = rate_to_ndx(sn, rate3);
 
@@ -623,7 +634,6 @@ ath_rate_ctl_reset(struct ath_softc *sc, struct ieee80211_node *ni)
 	const HAL_RATE_TABLE *rt = sc->sc_currates;
 	unsigned int x;
 	int retry_index, tx_time;
-	int srate;
 	int ndx = 0;
 
 	sn->num_rates = 0;
@@ -678,30 +688,24 @@ ath_rate_ctl_reset(struct ath_softc *sc, struct ieee80211_node *ni)
 	}
 
 	if (vap->iv_fixed_rate != IEEE80211_FIXED_RATE_NONE) {
-		srate = sn->num_rates - 1;
+		int srate;
 
-		/* A fixed rate is to be used; ic_fixed_rate is an
-		 * index into the supported rate set.  Convert this
-		 * to the index into the negotiated rate set for
-		 * the node.  We know the rate is there because the
-		 * rate set is checked when the station associates. */
-		/* NB: the rate set is assumed to be sorted. */
-		for (;
-				(srate >= 0) &&
-				(ni->ni_rates.rs_rates[srate] &
-				 IEEE80211_RATE_VAL) != vap->iv_fixed_rate;
-				srate--);
+		/*
+		 * A fixed rate is to be used.  Find the corresponding
+		 * index in the rate table.
+		 */
+		for (srate = 0; srate < sn->num_rates; srate++)
+			if (vap->iv_fixed_rate ==
+			    (ni->ni_rates.rs_rates[srate] & IEEE80211_RATE_VAL)) {
+				sn->static_rate_ndx = srate;
+				ni->ni_txrate = srate;
+				return;
+			}
 
-		KASSERT(srate >= 0,
-			("fixed rate %d not in rate set", vap->iv_fixed_rate));
-
-		sn->static_rate_ndx = srate;
-		ni->ni_txrate = srate;
-		DPRINTF(sc, "%s: %s " MAC_FMT " fixed rate %d%sMbps\n",
-			dev_info, __func__, MAC_ADDR(ni->ni_macaddr),
-			sn->rates[srate].rate / 2,
-			(sn->rates[srate].rate % 2) ? ".5 " : " ");
-		return;
+		printk(KERN_WARNING "%s: %s: fixed rate %u%sMbps is not "
+		       "available and will be ignored\n", vap->iv_dev->name,
+		       dev_info, vap->iv_fixed_rate / 2,
+		       (vap->iv_fixed_rate & 1) ? ".5" : "");
 	}
 
 	for (x = 0; x < ni->ni_rates.rs_nrates; x++) {
