@@ -33,7 +33,7 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
  * THE POSSIBILITY OF SUCH DAMAGES.
  *
- * $Id: sample.c 3902 2009-01-14 02:36:53Z proski $
+ * $Id: sample.c 4095 2009-09-03 21:08:13Z proski $
  */
 
 
@@ -681,31 +681,7 @@ ath_rate_tx_complete(struct ath_softc *sc,
 			MAC_ADDR(an->an_node.ni_macaddr), __func__);
 		return;
 	}
-
 	mrr = sc->sc_mrretry && !(ic->ic_flags & IEEE80211_F_USEPROT) && ENABLE_MRR;
-
-
-	if (sc->sc_mrretry && ts->ts_status) {
-		/* this packet failed */
-		DPRINTF(sc, ATH_DEBUG_RATE, "%s: " MAC_FMT " size %u rate/try %u/%u %u/%u %u/%u %u/%u status %s retries (%u/%u)\n",
-			dev_info,
-			MAC_ADDR(an->an_node.ni_macaddr),
-			bin_to_size(size_to_bin(frame_size)),
-			sc->sc_hwmap[MS(ds->ds_ctl3, AR_XmitRate0)].ieeerate,
-				MS(ds->ds_ctl2, AR_XmitDataTries0),
-			sc->sc_hwmap[MS(ds->ds_ctl3, AR_XmitRate1)].ieeerate,
-				MS(ds->ds_ctl2, AR_XmitDataTries1),
-			sc->sc_hwmap[MS(ds->ds_ctl3, AR_XmitRate2)].ieeerate,
-				MS(ds->ds_ctl2, AR_XmitDataTries2),
-			sc->sc_hwmap[MS(ds->ds_ctl3, AR_XmitRate3)].ieeerate,
-				MS(ds->ds_ctl2, AR_XmitDataTries3),
-			ts->ts_status ? "FAIL" : "OK",
-			short_tries, long_tries);
-	}
-
-	mrr = sc->sc_mrretry && !(ic->ic_flags & IEEE80211_F_USEPROT) && ENABLE_MRR;
-
-
 	if (!mrr || !(ts->ts_rate & HAL_TXSTAT_ALTRATE)) {
 		/* only one rate was used */
 		int ndx = rate_to_ndx(sn, final_rate);
@@ -718,7 +694,7 @@ ath_rate_tx_complete(struct ath_softc *sc,
 				short_tries, long_tries, ts->ts_status);
 		}
 	} else {
-		unsigned int rate[4], tries[4];
+		unsigned int rate[4], tries[4], hwrate[4];
 		int ndx[4];
 		int finalTSIdx = ts->ts_finaltsi;
 
@@ -726,19 +702,31 @@ ath_rate_tx_complete(struct ath_softc *sc,
 		 * Process intermediate rates that failed.
 		 */
 
-		rate[0] = sc->sc_hwmap[MS(ds->ds_ctl3, AR_XmitRate0)].ieeerate;
+		if (sc->sc_ah->ah_magic != 0x20065416) {
+			hwrate[0] = MS(ds->ds_ctl3, AR_XmitRate0);
+			hwrate[1] = MS(ds->ds_ctl3, AR_XmitRate1);
+			hwrate[2] = MS(ds->ds_ctl3, AR_XmitRate2);
+			hwrate[3] = MS(ds->ds_ctl3, AR_XmitRate3);
+		} else {
+			hwrate[0] = MS(ds->ds_ctl3, AR5416_XmitRate0);
+			hwrate[1] = MS(ds->ds_ctl3, AR5416_XmitRate1);
+			hwrate[2] = MS(ds->ds_ctl3, AR5416_XmitRate2);
+			hwrate[3] = MS(ds->ds_ctl3, AR5416_XmitRate3);
+		}
+
+		rate[0] = sc->sc_hwmap[hwrate[0]].ieeerate;
 		tries[0] = MS(ds->ds_ctl2, AR_XmitDataTries0);
 		ndx[0] = rate_to_ndx(sn, rate[0]);
 
-		rate[1] = sc->sc_hwmap[MS(ds->ds_ctl3, AR_XmitRate1)].ieeerate;
+		rate[1] = sc->sc_hwmap[hwrate[1]].ieeerate;
 		tries[1] = MS(ds->ds_ctl2, AR_XmitDataTries1);
 		ndx[1] = rate_to_ndx(sn, rate[1]);
 
-		rate[2] = sc->sc_hwmap[MS(ds->ds_ctl3, AR_XmitRate2)].ieeerate;
+		rate[2] = sc->sc_hwmap[hwrate[2]].ieeerate;
 		tries[2] = MS(ds->ds_ctl2, AR_XmitDataTries2);
 		ndx[2] = rate_to_ndx(sn, rate[2]);
 
-		rate[3] = sc->sc_hwmap[MS(ds->ds_ctl3, AR_XmitRate3)].ieeerate;
+		rate[3] = sc->sc_hwmap[hwrate[3]].ieeerate;
 		tries[3] = MS(ds->ds_ctl2, AR_XmitDataTries3);
 		ndx[3] = rate_to_ndx(sn, rate[3]);
 
@@ -748,7 +736,7 @@ ath_rate_tx_complete(struct ath_softc *sc,
 			bin_to_size(size_to_bin(frame_size)),
 			finalTSIdx,
 			long_tries,
-			ds->ds_txstat.ts_status,
+			ts->ts_status,
 			rate[0], tries[0],
 			rate[1], tries[1],
 			rate[2], tries[2],
@@ -828,7 +816,6 @@ ath_rate_ctl_reset(struct ath_softc *sc, struct ieee80211_node *ni)
 	struct ieee80211vap *vap = ni->ni_vap;
 	const HAL_RATE_TABLE *rt = sc->sc_currates;
 	unsigned int x, y;
-	unsigned int srate;
 
 	sn->num_rates = 0;
 
@@ -865,31 +852,26 @@ ath_rate_ctl_reset(struct ath_softc *sc, struct ieee80211_node *ni)
 	}
 
 	if (vap->iv_fixed_rate != IEEE80211_FIXED_RATE_NONE) {
+		int srate;
+
 		/*
-		 * A fixed rate is to be used; ic_fixed_rate is an
-		 * index into the supported rate set.  Convert this
-		 * to the index into the negotiated rate set for
-		 * the node.  We know the rate is there because the
-		 * rate set is checked when the station associates.
+		 * A fixed rate is to be used.  Find the corresponding
+		 * index in the rate table.
 		 */
-		/* NB: the rate set is assumed sorted */
-		for (x = 0, srate = 0; x < sn->num_rates; x++)
-			if ((ni->ni_rates.rs_rates[x] & IEEE80211_RATE_VAL) == vap->iv_fixed_rate)
-				srate = x;
+		for (srate = 0; srate < sn->num_rates; srate++)
+			if (vap->iv_fixed_rate ==
+			    (ni->ni_rates.rs_rates[srate] & IEEE80211_RATE_VAL)) {
+				sn->static_rate_ndx = srate;
+				ni->ni_txrate = srate;
+				return;
+			}
 
-		KASSERT(((ni->ni_rates.rs_rates[srate] & IEEE80211_RATE_VAL) == vap->iv_fixed_rate),
-			("fixed rate %u not in rate set", vap->iv_fixed_rate));
-
-		sn->static_rate_ndx = srate;
-		ni->ni_txrate = srate;
-		DPRINTF(sc, ATH_DEBUG_RATE, "%s: %s " MAC_FMT " fixed rate %u%sMbps\n",
-			dev_info, __func__, MAC_ADDR(ni->ni_macaddr),
-			sn->rates[srate].rate / 2,
-			(sn->rates[srate].rate % 0x1) ? ".5" : " ");
-		return;
+		printk(KERN_WARNING "%s: %s: fixed rate %u%sMbps is not "
+		       "available and will be ignored\n", vap->iv_dev->name,
+		       dev_info, vap->iv_fixed_rate / 2,
+		       (vap->iv_fixed_rate & 1) ? ".5" : "");
 	}
 
-
 	for (y = 0; y < NUM_PACKET_SIZE_BINS; y++) {
 		unsigned int size = bin_to_size(y);
 		int ndx = 0;
