@@ -29,7 +29,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: ieee80211_crypto.c 3162 2008-01-16 20:01:39Z mtaylor $
+ * $Id: ieee80211_crypto.c 3710 2008-06-06 20:32:29Z mentor $
  */
 #ifndef EXPORT_SYMTAB
 #define	EXPORT_SYMTAB
@@ -204,12 +204,12 @@ void
 ieee80211_crypto_register(const struct ieee80211_cipher *cip)
 {
 	if (cip->ic_cipher >= IEEE80211_CIPHER_MAX) {
-		printf("%s: cipher %s has an invalid cipher index %u\n",
+		printk(KERN_ERR "%s: cipher %s has an invalid cipher index %u\n",
 			__func__, cip->ic_name, cip->ic_cipher);
 		return;
 	}
 	if ((ciphers[cip->ic_cipher] != NULL) && (ciphers[cip->ic_cipher] != cip)) {
-		printf("%s: cipher %s registered with a different template\n",
+		printk(KERN_ERR "%s: cipher %s registered with a different template\n",
 			__func__, cip->ic_name);
 		return;
 	}
@@ -224,12 +224,12 @@ void
 ieee80211_crypto_unregister(const struct ieee80211_cipher *cip)
 {
 	if (cip->ic_cipher >= IEEE80211_CIPHER_MAX) {
-		printf("%s: cipher %s has an invalid cipher index %u\n",
+		printk(KERN_ERR "%s: cipher %s has an invalid cipher index %u\n",
 			__func__, cip->ic_name, cip->ic_cipher);
 		return;
 	}
 	if (ciphers[cip->ic_cipher] != NULL && ciphers[cip->ic_cipher] != cip) {
-		printf("%s: cipher %s registered with a different template\n",
+		printk(KERN_ERR "%s: cipher %s registered with a different template\n",
 			__func__, cip->ic_name);
 		return;
 	}
@@ -524,9 +524,9 @@ ieee80211_crypto_setkey(struct ieee80211vap *vap, struct ieee80211_key *key,
 	KASSERT(cip != NULL, ("No cipher!"));
 
 	IEEE80211_DPRINTF(vap, IEEE80211_MSG_CRYPTO,
-		"%s: %s keyix %u flags 0x%x mac %s  tsc %llu len %u\n", __func__,
+		"%s: %s keyix %u flags 0x%x mac " MAC_FMT "  tsc %llu len %u\n", __func__,
 		cip->ic_name, key->wk_keyix, key->wk_flags,
-		ether_sprintf(macaddr), (unsigned long long)key->wk_keytsc,
+		MAC_ADDR(macaddr), (unsigned long long)key->wk_keytsc,
 		key->wk_keylen);
 
 	/*
@@ -644,7 +644,7 @@ ieee80211_crypto_decap(struct ieee80211_node *ni, struct sk_buff *skb, int hdrle
 	 * This assumes unicast keys are only configured when
 	 * the key id in the header is meaningless (typically 0).
 	 */
-	wh = (struct ieee80211_frame *) skb->data;
+	wh = (struct ieee80211_frame *)skb->data;
 	ivp = skb->data + hdrlen;
 	keyid = ivp[IEEE80211_WEP_IVLEN];
 	if (IEEE80211_IS_MULTICAST(wh->i_addr1) ||
