@@ -28,7 +28,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: ieee80211_crypto_ccmp.c 2794 2007-10-28 20:40:04Z mtaylor $
+ * $Id: ieee80211_crypto_ccmp.c 3734 2008-06-19 16:58:07Z proski $
  */
 
 /*
@@ -73,7 +73,7 @@ static int ccmp_setkey(struct ieee80211_key *);
 static int ccmp_encap(struct ieee80211_key *, struct sk_buff *, u_int8_t);
 static int ccmp_decap(struct ieee80211_key *, struct sk_buff *, int);
 static int ccmp_enmic(struct ieee80211_key *, struct sk_buff *, int);
-static int ccmp_demic(struct ieee80211_key *, struct sk_buff *, int);
+static int ccmp_demic(struct ieee80211_key *, struct sk_buff *, int, int);
 
 static const struct ieee80211_cipher ccmp = {
 	.ic_name	= "AES-CCM",
@@ -98,6 +98,7 @@ static void *
 ccmp_attach(struct ieee80211vap *vap, struct ieee80211_key *k)
 {
 	struct ccmp_ctx *ctx;
+	int status = 1;
 
 	_MOD_INC_USE(THIS_MODULE, return NULL);
 
@@ -105,29 +106,39 @@ ccmp_attach(struct ieee80211vap *vap, struct ieee80211_key *k)
 		M_DEVBUF, M_NOWAIT | M_ZERO);
 	if (ctx == NULL) {
 		vap->iv_stats.is_crypto_nomem++;
-		_MOD_DEC_USE(THIS_MODULE);
-		return NULL;
+		status = 0;
 	}
 
-	ctx->cc_vap = vap;
-	ctx->cc_ic = vap->iv_ic;
-
-/* This function (crypto_alloc_foo might sleep. Therefore:
- * Context: process
- */
+/* This function crypto_alloc_foo might sleep. Therefore:
+ * Context: process */
+	if (k->wk_flags & IEEE80211_KEY_SWCRYPT) {
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,19)
-	ctx->cc_tfm = crypto_alloc_tfm("aes", 0);
+		ctx->cc_tfm = crypto_alloc_tfm("aes", 0);
 #else
-	ctx->cc_tfm = crypto_alloc_cipher("aes", 0,
-					CRYPTO_ALG_ASYNC);
-	if (IS_ERR(ctx->cc_tfm))
-		ctx->cc_tfm = NULL;
+		ctx->cc_tfm = crypto_alloc_cipher("aes", 0,
+				CRYPTO_ALG_ASYNC);
+		if (IS_ERR(ctx->cc_tfm))
+			ctx->cc_tfm = NULL;
 #endif
 	
-	if (ctx->cc_tfm == NULL) {
-		IEEE80211_DPRINTF(vap, IEEE80211_MSG_CRYPTO,
-				"%s: unable to load kernel AES crypto support\n",
-				__func__);
+		if (ctx->cc_tfm == NULL) {
+			IEEE80211_DPRINTF(vap, IEEE80211_MSG_CRYPTO,
+					"%s: kernel support for AES "
+					"cryptography is not available; the "
+					"module may not be loaded.\n", 
+					__func__);
+			FREE(ctx, M_DEVBUF);
+			ctx = NULL;
+			vap->iv_stats.is_crypto_nocipher++;
+			status = 0;
+		}
+	}
+
+	if (!status)
+		_MOD_DEC_USE(THIS_MODULE);
+	else {
+		ctx->cc_vap = vap;
+		ctx->cc_ic = vap->iv_ic;
 	}
 
 	return ctx;
@@ -161,16 +172,8 @@ ccmp_setkey(struct ieee80211_key *k)
 		return 0;
 	}
 
-	if (k->wk_flags & IEEE80211_KEY_SWCRYPT) {
-		if (ctx->cc_tfm == NULL) {
-			IEEE80211_DPRINTF(ctx->cc_vap, IEEE80211_MSG_CRYPTO,
-				"%s: Tried to add a software crypto key, but software crypto is not available\n",
-				__func__);
-			return 0;
-		}
-
+	if (k->wk_flags & IEEE80211_KEY_SWCRYPT)
 		crypto_cipher_setkey(ctx->cc_tfm, k->wk_key, k->wk_keylen);
-	}
 
 	return 1;
 }
@@ -219,7 +222,7 @@ ccmp_encap(struct ieee80211_key *k, struct sk_buff *skb, u_int8_t keyid)
  * Add MIC to the frame as needed.
  */
 static int
-ccmp_enmic(struct ieee80211_key *k, struct sk_buff *skb, int force)
+ccmp_enmic(struct ieee80211_key *k, struct sk_buff *skb, int force_sw)
 {
 	return 1;
 }
@@ -308,7 +311,7 @@ ccmp_decap(struct ieee80211_key *k, struct sk_buff *skb, int hdrlen)
  * Verify and strip MIC from the frame.
  */
 static int
-ccmp_demic(struct ieee80211_key *k, struct sk_buff *skb, int hdrlen)
+ccmp_demic(struct ieee80211_key *k, struct sk_buff *skb, int hdrlen, int force_sw)
 {
 	return 1;
 }
@@ -412,7 +415,7 @@ ccmp_init_blocks(struct crypto_cipher *tfm, struct ieee80211_frame *wh,
 			((struct ieee80211_frame_addr4 *)wh)->i_addr4);
 		if (IS_QOS_DATA(wh)) {
 			struct ieee80211_qosframe_addr4 *qwh4 =
-				(struct ieee80211_qosframe_addr4 *) wh;
+				(struct ieee80211_qosframe_addr4 *)wh;
 			aad[30] = qwh4->i_qos[0] & 0x0f;/* just priority bits */
 			aad[31] = 0;
 			b0[1] = aad[30];
@@ -425,7 +428,7 @@ ccmp_init_blocks(struct crypto_cipher *tfm, struct ieee80211_frame *wh,
 	} else {
 		if (IS_QOS_DATA(wh)) {
 			struct ieee80211_qosframe *qwh =
-				(struct ieee80211_qosframe*) wh;
+				(struct ieee80211_qosframe *)wh;
 			aad[24] = qwh->i_qos[0] & 0x0f;	/* just priority bits */
 			aad[25] = 0;
 			b0[1] = aad[24];
@@ -467,7 +470,7 @@ static int
 ccmp_encrypt(struct ieee80211_key *key, struct sk_buff *skb0, int hdrlen)
 {
 	struct ccmp_ctx *ctx = key->wk_private;
-	struct ieee80211_frame *wh = (struct ieee80211_frame *) skb0->data;
+	struct ieee80211_frame *wh = (struct ieee80211_frame *)skb0->data;
 	struct sk_buff *skb;
 	int data_len, i;
 	uint8_t aad[2 * AES_BLOCK_LEN], b0[AES_BLOCK_LEN], b[AES_BLOCK_LEN];
@@ -538,7 +541,7 @@ ccmp_encrypt(struct ieee80211_key *key, struct sk_buff *skb0, int hdrlen)
 			space_next = len > space ? len - space : 0;
 			KASSERT(skb->len >= space_next,
 				("not enough data in following buffer, "
-				"skb len %u need %u\n", skb->len, space_next));
+				"skb len %u need %u", skb->len, space_next));
 
 			xor_block(b + space, pos_next, space_next);
 			CCMP_ENCRYPT(i, b, b0, pos, e, space);
@@ -580,7 +583,7 @@ static int
 ccmp_decrypt(struct ieee80211_key *key, u_int64_t pn, struct sk_buff *skb0, int hdrlen)
 {
 	struct ccmp_ctx *ctx = key->wk_private;
-	struct ieee80211_frame *wh = (struct ieee80211_frame *) skb0->data;
+	struct ieee80211_frame *wh = (struct ieee80211_frame *)skb0->data;
 	struct sk_buff *skb;
 	uint8_t aad[2 * AES_BLOCK_LEN];
 	uint8_t b0[AES_BLOCK_LEN], b[AES_BLOCK_LEN], a[AES_BLOCK_LEN];
@@ -641,7 +644,7 @@ ccmp_decrypt(struct ieee80211_key *key, u_int64_t pn, struct sk_buff *skb0, int
 			space_next = len > space ? len - space : 0;
 			KASSERT(skb->len >= space_next,
 				("not enough data in following buffer, "
-				"skb len %u need %u\n", skb->len, space_next));
+				"skb len %u need %u", skb->len, space_next));
 
 			xor_block(b+space, pos_next, space_next);
 			CCMP_DECRYPT(i, b, b0, pos, a, space);
